document.addEventListener('DOMContentLoaded', () => {
  const cellCanvas = document.getElementById('cellCanvas');
  const particles = [];
  let animationId;

  class Particle {
    constructor() {
      this.element = document.createElement('div');
      this.element.className = 'particle';
      this.x = Math.random() * cellCanvas.offsetWidth;
      this.y = Math.random() * cellCanvas.offsetHeight;
      this.vx = (Math.random() - 0.5) * 2;
      this.vy = (Math.random() - 0.5) * 2;
      this.radius = cellCanvas.offsetWidth / 2;
      this.centerX = cellCanvas.offsetWidth / 2;
      this.centerY = cellCanvas.offsetHeight / 2;
      cellCanvas.appendChild(this.element);
    }

    update() {
      this.x += this.vx;
      this.y += this.vy;

      const dx = this.x - this.centerX;
      const dy = this.y - this.centerY;
      const distance = Math.sqrt(dx * dx + dy * dy);

      if (distance > this.radius - 4) {
        const angle = Math.atan2(dy, dx);
        this.vx = Math.cos(angle) * 1.5;
        this.vy = Math.sin(angle) * 1.5;
      }

      this.element.style.transform = `translate(${this.x}px, ${this.y}px)`;
    }
  }

  function initParticles() {
    for (let i = 0; i < 200; i++) {
      particles.push(new Particle());
    }
  }

  function animate() {
    particles.forEach(particle => particle.update());
    animationId = requestAnimationFrame(animate);
  }

  function resetSimulation() {
    particles.forEach(particle => particle.element.remove());
    particles.length = 0;
    initParticles();
  }

  function handleResize() {
    cancelAnimationFrame(animationId);
    cellCanvas.innerHTML = '';
    initParticles();
    animate();
  }

  window.addEventListener('resize', handleResize);
  document.getElementById('resetParticles').addEventListener('click', resetSimulation);

  initParticles();
  animate();
});